metadata(version="0.2.5")

# Originally written by Paul Sokolovsky.

require("ffilib")

module("re.py")
